# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class JsonNode(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        JsonNode - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'node_type': 'str',
            'float': 'bool',
            'object': 'bool',
            'boolean': 'bool',
            'number': 'bool',
            'value_node': 'bool',
            'container_node': 'bool',
            'missing_node': 'bool',
            'pojo': 'bool',
            'integral_number': 'bool',
            'floating_point_number': 'bool',
            'short': 'bool',
            'int': 'bool',
            'long': 'bool',
            'double': 'bool',
            'big_decimal': 'bool',
            'big_integer': 'bool',
            'textual': 'bool',
            'binary': 'bool',
            'array': 'bool',
            'null': 'bool'
        }

        self.attribute_map = {
            'node_type': 'nodeType',
            'float': 'float',
            'object': 'object',
            'boolean': 'boolean',
            'number': 'number',
            'value_node': 'valueNode',
            'container_node': 'containerNode',
            'missing_node': 'missingNode',
            'pojo': 'pojo',
            'integral_number': 'integralNumber',
            'floating_point_number': 'floatingPointNumber',
            'short': 'short',
            'int': 'int',
            'long': 'long',
            'double': 'double',
            'big_decimal': 'bigDecimal',
            'big_integer': 'bigInteger',
            'textual': 'textual',
            'binary': 'binary',
            'array': 'array',
            'null': 'null'
        }

        self._node_type = None
        self._float = False
        self._object = False
        self._boolean = False
        self._number = False
        self._value_node = False
        self._container_node = False
        self._missing_node = False
        self._pojo = False
        self._integral_number = False
        self._floating_point_number = False
        self._short = False
        self._int = False
        self._long = False
        self._double = False
        self._big_decimal = False
        self._big_integer = False
        self._textual = False
        self._binary = False
        self._array = False
        self._null = False

    @property
    def node_type(self):
        """
        Gets the node_type of this JsonNode.


        :return: The node_type of this JsonNode.
        :rtype: str
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """
        Sets the node_type of this JsonNode.


        :param node_type: The node_type of this JsonNode.
        :type: str
        """
        allowed_values = ["ARRAY", "BINARY", "BOOLEAN", "MISSING", "NULL", "NUMBER", "OBJECT", "POJO", "STRING"]
        if node_type not in allowed_values:
            raise ValueError(
                "Invalid value for `node_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._node_type = node_type

    @property
    def float(self):
        """
        Gets the float of this JsonNode.


        :return: The float of this JsonNode.
        :rtype: bool
        """
        return self._float

    @float.setter
    def float(self, float):
        """
        Sets the float of this JsonNode.


        :param float: The float of this JsonNode.
        :type: bool
        """
        self._float = float

    @property
    def object(self):
        """
        Gets the object of this JsonNode.


        :return: The object of this JsonNode.
        :rtype: bool
        """
        return self._object

    @object.setter
    def object(self, object):
        """
        Sets the object of this JsonNode.


        :param object: The object of this JsonNode.
        :type: bool
        """
        self._object = object

    @property
    def boolean(self):
        """
        Gets the boolean of this JsonNode.


        :return: The boolean of this JsonNode.
        :rtype: bool
        """
        return self._boolean

    @boolean.setter
    def boolean(self, boolean):
        """
        Sets the boolean of this JsonNode.


        :param boolean: The boolean of this JsonNode.
        :type: bool
        """
        self._boolean = boolean

    @property
    def number(self):
        """
        Gets the number of this JsonNode.


        :return: The number of this JsonNode.
        :rtype: bool
        """
        return self._number

    @number.setter
    def number(self, number):
        """
        Sets the number of this JsonNode.


        :param number: The number of this JsonNode.
        :type: bool
        """
        self._number = number

    @property
    def value_node(self):
        """
        Gets the value_node of this JsonNode.


        :return: The value_node of this JsonNode.
        :rtype: bool
        """
        return self._value_node

    @value_node.setter
    def value_node(self, value_node):
        """
        Sets the value_node of this JsonNode.


        :param value_node: The value_node of this JsonNode.
        :type: bool
        """
        self._value_node = value_node

    @property
    def container_node(self):
        """
        Gets the container_node of this JsonNode.


        :return: The container_node of this JsonNode.
        :rtype: bool
        """
        return self._container_node

    @container_node.setter
    def container_node(self, container_node):
        """
        Sets the container_node of this JsonNode.


        :param container_node: The container_node of this JsonNode.
        :type: bool
        """
        self._container_node = container_node

    @property
    def missing_node(self):
        """
        Gets the missing_node of this JsonNode.


        :return: The missing_node of this JsonNode.
        :rtype: bool
        """
        return self._missing_node

    @missing_node.setter
    def missing_node(self, missing_node):
        """
        Sets the missing_node of this JsonNode.


        :param missing_node: The missing_node of this JsonNode.
        :type: bool
        """
        self._missing_node = missing_node

    @property
    def pojo(self):
        """
        Gets the pojo of this JsonNode.


        :return: The pojo of this JsonNode.
        :rtype: bool
        """
        return self._pojo

    @pojo.setter
    def pojo(self, pojo):
        """
        Sets the pojo of this JsonNode.


        :param pojo: The pojo of this JsonNode.
        :type: bool
        """
        self._pojo = pojo

    @property
    def integral_number(self):
        """
        Gets the integral_number of this JsonNode.


        :return: The integral_number of this JsonNode.
        :rtype: bool
        """
        return self._integral_number

    @integral_number.setter
    def integral_number(self, integral_number):
        """
        Sets the integral_number of this JsonNode.


        :param integral_number: The integral_number of this JsonNode.
        :type: bool
        """
        self._integral_number = integral_number

    @property
    def floating_point_number(self):
        """
        Gets the floating_point_number of this JsonNode.


        :return: The floating_point_number of this JsonNode.
        :rtype: bool
        """
        return self._floating_point_number

    @floating_point_number.setter
    def floating_point_number(self, floating_point_number):
        """
        Sets the floating_point_number of this JsonNode.


        :param floating_point_number: The floating_point_number of this JsonNode.
        :type: bool
        """
        self._floating_point_number = floating_point_number

    @property
    def short(self):
        """
        Gets the short of this JsonNode.


        :return: The short of this JsonNode.
        :rtype: bool
        """
        return self._short

    @short.setter
    def short(self, short):
        """
        Sets the short of this JsonNode.


        :param short: The short of this JsonNode.
        :type: bool
        """
        self._short = short

    @property
    def int(self):
        """
        Gets the int of this JsonNode.


        :return: The int of this JsonNode.
        :rtype: bool
        """
        return self._int

    @int.setter
    def int(self, int):
        """
        Sets the int of this JsonNode.


        :param int: The int of this JsonNode.
        :type: bool
        """
        self._int = int

    @property
    def long(self):
        """
        Gets the long of this JsonNode.


        :return: The long of this JsonNode.
        :rtype: bool
        """
        return self._long

    @long.setter
    def long(self, long):
        """
        Sets the long of this JsonNode.


        :param long: The long of this JsonNode.
        :type: bool
        """
        self._long = long

    @property
    def double(self):
        """
        Gets the double of this JsonNode.


        :return: The double of this JsonNode.
        :rtype: bool
        """
        return self._double

    @double.setter
    def double(self, double):
        """
        Sets the double of this JsonNode.


        :param double: The double of this JsonNode.
        :type: bool
        """
        self._double = double

    @property
    def big_decimal(self):
        """
        Gets the big_decimal of this JsonNode.


        :return: The big_decimal of this JsonNode.
        :rtype: bool
        """
        return self._big_decimal

    @big_decimal.setter
    def big_decimal(self, big_decimal):
        """
        Sets the big_decimal of this JsonNode.


        :param big_decimal: The big_decimal of this JsonNode.
        :type: bool
        """
        self._big_decimal = big_decimal

    @property
    def big_integer(self):
        """
        Gets the big_integer of this JsonNode.


        :return: The big_integer of this JsonNode.
        :rtype: bool
        """
        return self._big_integer

    @big_integer.setter
    def big_integer(self, big_integer):
        """
        Sets the big_integer of this JsonNode.


        :param big_integer: The big_integer of this JsonNode.
        :type: bool
        """
        self._big_integer = big_integer

    @property
    def textual(self):
        """
        Gets the textual of this JsonNode.


        :return: The textual of this JsonNode.
        :rtype: bool
        """
        return self._textual

    @textual.setter
    def textual(self, textual):
        """
        Sets the textual of this JsonNode.


        :param textual: The textual of this JsonNode.
        :type: bool
        """
        self._textual = textual

    @property
    def binary(self):
        """
        Gets the binary of this JsonNode.


        :return: The binary of this JsonNode.
        :rtype: bool
        """
        return self._binary

    @binary.setter
    def binary(self, binary):
        """
        Sets the binary of this JsonNode.


        :param binary: The binary of this JsonNode.
        :type: bool
        """
        self._binary = binary

    @property
    def array(self):
        """
        Gets the array of this JsonNode.


        :return: The array of this JsonNode.
        :rtype: bool
        """
        return self._array

    @array.setter
    def array(self, array):
        """
        Sets the array of this JsonNode.


        :param array: The array of this JsonNode.
        :type: bool
        """
        self._array = array

    @property
    def null(self):
        """
        Gets the null of this JsonNode.


        :return: The null of this JsonNode.
        :rtype: bool
        """
        return self._null

    @null.setter
    def null(self, null):
        """
        Sets the null of this JsonNode.


        :param null: The null of this JsonNode.
        :type: bool
        """
        self._null = null

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class VoiceXmlOperation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VoiceXmlOperation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'type': 'str',
            'method': 'str',
            'encoding': 'str',
            'description': 'str',
            'uri': 'str',
            'inputs': 'str',
            'outputs': 'str',
            'fetch_audio': 'str',
            'timeout_ms': 'int',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'type': 'type',
            'method': 'method',
            'encoding': 'encoding',
            'description': 'description',
            'uri': 'uri',
            'inputs': 'inputs',
            'outputs': 'outputs',
            'fetch_audio': 'fetchAudio',
            'timeout_ms': 'timeoutMS',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._type = None
        self._method = None
        self._encoding = None
        self._description = None
        self._uri = None
        self._inputs = None
        self._outputs = None
        self._fetch_audio = None
        self._timeout_ms = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this VoiceXmlOperation.
        The globally unique identifier for the object.

        :return: The id of this VoiceXmlOperation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VoiceXmlOperation.
        The globally unique identifier for the object.

        :param id: The id of this VoiceXmlOperation.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this VoiceXmlOperation.


        :return: The name of this VoiceXmlOperation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this VoiceXmlOperation.


        :param name: The name of this VoiceXmlOperation.
        :type: str
        """
        self._name = name

    @property
    def type(self):
        """
        Gets the type of this VoiceXmlOperation.


        :return: The type of this VoiceXmlOperation.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this VoiceXmlOperation.


        :param type: The type of this VoiceXmlOperation.
        :type: str
        """
        allowed_values = ["GOTO", "CALL_AND_RETURN"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def method(self):
        """
        Gets the method of this VoiceXmlOperation.


        :return: The method of this VoiceXmlOperation.
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """
        Sets the method of this VoiceXmlOperation.


        :param method: The method of this VoiceXmlOperation.
        :type: str
        """
        allowed_values = ["GET", "PUT", "POST", "DELETE"]
        if method not in allowed_values:
            raise ValueError(
                "Invalid value for `method`, must be one of {0}"
                .format(allowed_values)
            )
        self._method = method

    @property
    def encoding(self):
        """
        Gets the encoding of this VoiceXmlOperation.


        :return: The encoding of this VoiceXmlOperation.
        :rtype: str
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding):
        """
        Sets the encoding of this VoiceXmlOperation.


        :param encoding: The encoding of this VoiceXmlOperation.
        :type: str
        """
        allowed_values = ["MULTIPART_FORM_DATA", "FORM_URL_ENCODED", "JSON"]
        if encoding not in allowed_values:
            raise ValueError(
                "Invalid value for `encoding`, must be one of {0}"
                .format(allowed_values)
            )
        self._encoding = encoding

    @property
    def description(self):
        """
        Gets the description of this VoiceXmlOperation.


        :return: The description of this VoiceXmlOperation.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this VoiceXmlOperation.


        :param description: The description of this VoiceXmlOperation.
        :type: str
        """
        self._description = description

    @property
    def uri(self):
        """
        Gets the uri of this VoiceXmlOperation.


        :return: The uri of this VoiceXmlOperation.
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """
        Sets the uri of this VoiceXmlOperation.


        :param uri: The uri of this VoiceXmlOperation.
        :type: str
        """
        self._uri = uri

    @property
    def inputs(self):
        """
        Gets the inputs of this VoiceXmlOperation.


        :return: The inputs of this VoiceXmlOperation.
        :rtype: str
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """
        Sets the inputs of this VoiceXmlOperation.


        :param inputs: The inputs of this VoiceXmlOperation.
        :type: str
        """
        self._inputs = inputs

    @property
    def outputs(self):
        """
        Gets the outputs of this VoiceXmlOperation.


        :return: The outputs of this VoiceXmlOperation.
        :rtype: str
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """
        Sets the outputs of this VoiceXmlOperation.


        :param outputs: The outputs of this VoiceXmlOperation.
        :type: str
        """
        self._outputs = outputs

    @property
    def fetch_audio(self):
        """
        Gets the fetch_audio of this VoiceXmlOperation.


        :return: The fetch_audio of this VoiceXmlOperation.
        :rtype: str
        """
        return self._fetch_audio

    @fetch_audio.setter
    def fetch_audio(self, fetch_audio):
        """
        Sets the fetch_audio of this VoiceXmlOperation.


        :param fetch_audio: The fetch_audio of this VoiceXmlOperation.
        :type: str
        """
        self._fetch_audio = fetch_audio

    @property
    def timeout_ms(self):
        """
        Gets the timeout_ms of this VoiceXmlOperation.


        :return: The timeout_ms of this VoiceXmlOperation.
        :rtype: int
        """
        return self._timeout_ms

    @timeout_ms.setter
    def timeout_ms(self, timeout_ms):
        """
        Sets the timeout_ms of this VoiceXmlOperation.


        :param timeout_ms: The timeout_ms of this VoiceXmlOperation.
        :type: int
        """
        self._timeout_ms = timeout_ms

    @property
    def self_uri(self):
        """
        Gets the self_uri of this VoiceXmlOperation.
        The URI for this object

        :return: The self_uri of this VoiceXmlOperation.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this VoiceXmlOperation.
        The URI for this object

        :param self_uri: The self_uri of this VoiceXmlOperation.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class ExpressionResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ExpressionResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'social_hub': 'str',
            'conversation': 'Conversation',
            'twitter_expression': 'TwitterExpression',
            'raw_response_text': 'str',
            'social_account': 'SocialAccount',
            'social_hub_response_id': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'social_hub': 'socialHub',
            'conversation': 'conversation',
            'twitter_expression': 'twitterExpression',
            'raw_response_text': 'rawResponseText',
            'social_account': 'socialAccount',
            'social_hub_response_id': 'socialHubResponseId',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._social_hub = None
        self._conversation = None
        self._twitter_expression = None
        self._raw_response_text = None
        self._social_account = None
        self._social_hub_response_id = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ExpressionResponse.
        The globally unique identifier for the object.

        :return: The id of this ExpressionResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ExpressionResponse.
        The globally unique identifier for the object.

        :param id: The id of this ExpressionResponse.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ExpressionResponse.


        :return: The name of this ExpressionResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ExpressionResponse.


        :param name: The name of this ExpressionResponse.
        :type: str
        """
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this ExpressionResponse.
        Creation date for the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this ExpressionResponse.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this ExpressionResponse.
        Creation date for the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this ExpressionResponse.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this ExpressionResponse.
        Date the entity was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this ExpressionResponse.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this ExpressionResponse.
        Date the entity was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this ExpressionResponse.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def social_hub(self):
        """
        Gets the social_hub of this ExpressionResponse.
        The name of the social hub.

        :return: The social_hub of this ExpressionResponse.
        :rtype: str
        """
        return self._social_hub

    @social_hub.setter
    def social_hub(self, social_hub):
        """
        Sets the social_hub of this ExpressionResponse.
        The name of the social hub.

        :param social_hub: The social_hub of this ExpressionResponse.
        :type: str
        """
        self._social_hub = social_hub

    @property
    def conversation(self):
        """
        Gets the conversation of this ExpressionResponse.
        The conversation that this response is a part of.

        :return: The conversation of this ExpressionResponse.
        :rtype: Conversation
        """
        return self._conversation

    @conversation.setter
    def conversation(self, conversation):
        """
        Sets the conversation of this ExpressionResponse.
        The conversation that this response is a part of.

        :param conversation: The conversation of this ExpressionResponse.
        :type: Conversation
        """
        self._conversation = conversation

    @property
    def twitter_expression(self):
        """
        Gets the twitter_expression of this ExpressionResponse.
        The twitter expression that this is in response to.

        :return: The twitter_expression of this ExpressionResponse.
        :rtype: TwitterExpression
        """
        return self._twitter_expression

    @twitter_expression.setter
    def twitter_expression(self, twitter_expression):
        """
        Sets the twitter_expression of this ExpressionResponse.
        The twitter expression that this is in response to.

        :param twitter_expression: The twitter_expression of this ExpressionResponse.
        :type: TwitterExpression
        """
        self._twitter_expression = twitter_expression

    @property
    def raw_response_text(self):
        """
        Gets the raw_response_text of this ExpressionResponse.
        The raw text of the response.

        :return: The raw_response_text of this ExpressionResponse.
        :rtype: str
        """
        return self._raw_response_text

    @raw_response_text.setter
    def raw_response_text(self, raw_response_text):
        """
        Sets the raw_response_text of this ExpressionResponse.
        The raw text of the response.

        :param raw_response_text: The raw_response_text of this ExpressionResponse.
        :type: str
        """
        self._raw_response_text = raw_response_text

    @property
    def social_account(self):
        """
        Gets the social_account of this ExpressionResponse.
        The Social Account used to publish this expression

        :return: The social_account of this ExpressionResponse.
        :rtype: SocialAccount
        """
        return self._social_account

    @social_account.setter
    def social_account(self, social_account):
        """
        Sets the social_account of this ExpressionResponse.
        The Social Account used to publish this expression

        :param social_account: The social_account of this ExpressionResponse.
        :type: SocialAccount
        """
        self._social_account = social_account

    @property
    def social_hub_response_id(self):
        """
        Gets the social_hub_response_id of this ExpressionResponse.
        The id given to this response from the social hub

        :return: The social_hub_response_id of this ExpressionResponse.
        :rtype: str
        """
        return self._social_hub_response_id

    @social_hub_response_id.setter
    def social_hub_response_id(self, social_hub_response_id):
        """
        Sets the social_hub_response_id of this ExpressionResponse.
        The id given to this response from the social hub

        :param social_hub_response_id: The social_hub_response_id of this ExpressionResponse.
        :type: str
        """
        self._social_hub_response_id = social_hub_response_id

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ExpressionResponse.
        The URI for this object

        :return: The self_uri of this ExpressionResponse.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ExpressionResponse.
        The URI for this object

        :param self_uri: The self_uri of this ExpressionResponse.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class NumberPlan(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        NumberPlan - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'match': 'str',
            'normalized_format': 'str',
            'priority': 'int',
            'numbers': 'list[Number]',
            'digit_length': 'DigitLength',
            'classification': 'str',
            'match_type': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'match': 'match',
            'normalized_format': 'normalizedFormat',
            'priority': 'priority',
            'numbers': 'numbers',
            'digit_length': 'digitLength',
            'classification': 'classification',
            'match_type': 'matchType',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._match = None
        self._normalized_format = None
        self._priority = None
        self._numbers = None
        self._digit_length = None
        self._classification = None
        self._match_type = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this NumberPlan.
        The globally unique identifier for the object.

        :return: The id of this NumberPlan.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this NumberPlan.
        The globally unique identifier for the object.

        :param id: The id of this NumberPlan.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this NumberPlan.


        :return: The name of this NumberPlan.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this NumberPlan.


        :param name: The name of this NumberPlan.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this NumberPlan.


        :return: The description of this NumberPlan.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this NumberPlan.


        :param description: The description of this NumberPlan.
        :type: str
        """
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this NumberPlan.


        :return: The version of this NumberPlan.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this NumberPlan.


        :param version: The version of this NumberPlan.
        :type: int
        """
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this NumberPlan.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this NumberPlan.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this NumberPlan.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this NumberPlan.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this NumberPlan.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this NumberPlan.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this NumberPlan.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this NumberPlan.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this NumberPlan.


        :return: The modified_by of this NumberPlan.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this NumberPlan.


        :param modified_by: The modified_by of this NumberPlan.
        :type: str
        """
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this NumberPlan.


        :return: The created_by of this NumberPlan.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this NumberPlan.


        :param created_by: The created_by of this NumberPlan.
        :type: str
        """
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this NumberPlan.


        :return: The state of this NumberPlan.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this NumberPlan.


        :param state: The state of this NumberPlan.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this NumberPlan.


        :return: The modified_by_app of this NumberPlan.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this NumberPlan.


        :param modified_by_app: The modified_by_app of this NumberPlan.
        :type: str
        """
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this NumberPlan.


        :return: The created_by_app of this NumberPlan.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this NumberPlan.


        :param created_by_app: The created_by_app of this NumberPlan.
        :type: str
        """
        self._created_by_app = created_by_app

    @property
    def match(self):
        """
        Gets the match of this NumberPlan.


        :return: The match of this NumberPlan.
        :rtype: str
        """
        return self._match

    @match.setter
    def match(self, match):
        """
        Sets the match of this NumberPlan.


        :param match: The match of this NumberPlan.
        :type: str
        """
        self._match = match

    @property
    def normalized_format(self):
        """
        Gets the normalized_format of this NumberPlan.


        :return: The normalized_format of this NumberPlan.
        :rtype: str
        """
        return self._normalized_format

    @normalized_format.setter
    def normalized_format(self, normalized_format):
        """
        Sets the normalized_format of this NumberPlan.


        :param normalized_format: The normalized_format of this NumberPlan.
        :type: str
        """
        self._normalized_format = normalized_format

    @property
    def priority(self):
        """
        Gets the priority of this NumberPlan.


        :return: The priority of this NumberPlan.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this NumberPlan.


        :param priority: The priority of this NumberPlan.
        :type: int
        """
        self._priority = priority

    @property
    def numbers(self):
        """
        Gets the numbers of this NumberPlan.


        :return: The numbers of this NumberPlan.
        :rtype: list[Number]
        """
        return self._numbers

    @numbers.setter
    def numbers(self, numbers):
        """
        Sets the numbers of this NumberPlan.


        :param numbers: The numbers of this NumberPlan.
        :type: list[Number]
        """
        self._numbers = numbers

    @property
    def digit_length(self):
        """
        Gets the digit_length of this NumberPlan.


        :return: The digit_length of this NumberPlan.
        :rtype: DigitLength
        """
        return self._digit_length

    @digit_length.setter
    def digit_length(self, digit_length):
        """
        Sets the digit_length of this NumberPlan.


        :param digit_length: The digit_length of this NumberPlan.
        :type: DigitLength
        """
        self._digit_length = digit_length

    @property
    def classification(self):
        """
        Gets the classification of this NumberPlan.


        :return: The classification of this NumberPlan.
        :rtype: str
        """
        return self._classification

    @classification.setter
    def classification(self, classification):
        """
        Sets the classification of this NumberPlan.


        :param classification: The classification of this NumberPlan.
        :type: str
        """
        self._classification = classification

    @property
    def match_type(self):
        """
        Gets the match_type of this NumberPlan.
        The type of matching technique the number plan uses.

        :return: The match_type of this NumberPlan.
        :rtype: str
        """
        return self._match_type

    @match_type.setter
    def match_type(self, match_type):
        """
        Sets the match_type of this NumberPlan.
        The type of matching technique the number plan uses.

        :param match_type: The match_type of this NumberPlan.
        :type: str
        """
        allowed_values = ["e164NumberList", "numberList", "digitLength", "regex", "intraCountryCode", "interCountryCode"]
        if match_type not in allowed_values:
            raise ValueError(
                "Invalid value for `match_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._match_type = match_type

    @property
    def self_uri(self):
        """
        Gets the self_uri of this NumberPlan.
        The URI for this object

        :return: The self_uri of this NumberPlan.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this NumberPlan.
        The URI for this object

        :param self_uri: The self_uri of this NumberPlan.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Value(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Value - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'string_items': 'list[str]',
            'integer_items': 'list[str]',
            'real_items': 'list[str]',
            'date_items': 'list[datetime]',
            'user_items': 'list[User]',
            'queue_items': 'list[Queue]',
            'data_items': 'list[SubDataItem]'
        }

        self.attribute_map = {
            'string_items': 'stringItems',
            'integer_items': 'integerItems',
            'real_items': 'realItems',
            'date_items': 'dateItems',
            'user_items': 'userItems',
            'queue_items': 'queueItems',
            'data_items': 'dataItems'
        }

        self._string_items = None
        self._integer_items = None
        self._real_items = None
        self._date_items = None
        self._user_items = None
        self._queue_items = None
        self._data_items = None

    @property
    def string_items(self):
        """
        Gets the string_items of this Value.


        :return: The string_items of this Value.
        :rtype: list[str]
        """
        return self._string_items

    @string_items.setter
    def string_items(self, string_items):
        """
        Sets the string_items of this Value.


        :param string_items: The string_items of this Value.
        :type: list[str]
        """
        self._string_items = string_items

    @property
    def integer_items(self):
        """
        Gets the integer_items of this Value.


        :return: The integer_items of this Value.
        :rtype: list[str]
        """
        return self._integer_items

    @integer_items.setter
    def integer_items(self, integer_items):
        """
        Sets the integer_items of this Value.


        :param integer_items: The integer_items of this Value.
        :type: list[str]
        """
        self._integer_items = integer_items

    @property
    def real_items(self):
        """
        Gets the real_items of this Value.


        :return: The real_items of this Value.
        :rtype: list[str]
        """
        return self._real_items

    @real_items.setter
    def real_items(self, real_items):
        """
        Sets the real_items of this Value.


        :param real_items: The real_items of this Value.
        :type: list[str]
        """
        self._real_items = real_items

    @property
    def date_items(self):
        """
        Gets the date_items of this Value.


        :return: The date_items of this Value.
        :rtype: list[datetime]
        """
        return self._date_items

    @date_items.setter
    def date_items(self, date_items):
        """
        Sets the date_items of this Value.


        :param date_items: The date_items of this Value.
        :type: list[datetime]
        """
        self._date_items = date_items

    @property
    def user_items(self):
        """
        Gets the user_items of this Value.


        :return: The user_items of this Value.
        :rtype: list[User]
        """
        return self._user_items

    @user_items.setter
    def user_items(self, user_items):
        """
        Sets the user_items of this Value.


        :param user_items: The user_items of this Value.
        :type: list[User]
        """
        self._user_items = user_items

    @property
    def queue_items(self):
        """
        Gets the queue_items of this Value.


        :return: The queue_items of this Value.
        :rtype: list[Queue]
        """
        return self._queue_items

    @queue_items.setter
    def queue_items(self, queue_items):
        """
        Sets the queue_items of this Value.


        :param queue_items: The queue_items of this Value.
        :type: list[Queue]
        """
        self._queue_items = queue_items

    @property
    def data_items(self):
        """
        Gets the data_items of this Value.


        :return: The data_items of this Value.
        :rtype: list[SubDataItem]
        """
        return self._data_items

    @data_items.setter
    def data_items(self, data_items):
        """
        Sets the data_items of this Value.


        :param data_items: The data_items of this Value.
        :type: list[SubDataItem]
        """
        self._data_items = data_items

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

